#
# spec file for package velero
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           velero
Version:        1.12.2
Release:        1.1
Summary:        Backup program with deduplication and encryption
License:        Apache-2.0
Group:          Productivity/Archiving/Backup
URL:            https://velero.io
Source0:        https://github.com/vmware-tanzu/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.20

%description
velero is a backup program. It supports verification, encryption,
snapshots and deduplication.

%package velero-restic-restore-helper
Summary:        Restic restore helper for %{name}
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Supplements:    packageand(velero:velero-restic-restore-helper)

%description velero-restic-restore-helper
Restic restore helper for %{name}.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -q -a1

%build
go build \
   -installsuffix "static" \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.Version=%{version} \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.GitSHA=v%{version} \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.GitTreeState=clean" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files bash-completion
%defattr(-,root,root)
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%files fish-completion
%defattr(-,root,root)
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Mon Nov 27 2023 kastl@b1-systems.de
- Update to version 1.12.2:
  * RM support for Escaped bool, float, null (#7118) (#7131)
  * Add v1.12.2 changelog
  * revert test changes
  * `make update`
  * update changelog to reflect removed waits
  * CSIFeatureFlag enable check
  * remove waiting during finalize
  * skip this if SnapshotMoveData
  * refactor backup snapshot status updates into
    UpdateBackupSnapshotsStatus() and run in
    backup_finalizer_controller
  * Add PatchResource unit test for backup status
  * Issue 7068: add a finalizer to protect retained VSC
  * Bump up Velero base image to latest patch release
  * update changelog
  * Merge pull request #6917 from 27149chen/rm-improvement
  * Fix node-agent missing metrics-addr parms to define the server
    start.
  * issue 7094: fallback to full backup if previous snapshot is not
    found
  * Add DataUpload Result and CSI VolumeSnapshot check for restore
    PV.
  * Truncate the credential file to avoid the change of secret
    content messing it up
  * issue 7027: backup exposer -- don't assume first volume as the
    backup volume
  * restore: Use warning when Create IsAlreadyExist and Get error
    (#7004)
  * Read information from the credential specified by BSL
  * Make configmapref check case insensitive (#6804) (#7023)
  * Fix issue 6913
  * CVE-2023-44487 gRPC-Go HTTP/2 Rapid Reset vulnerability
  * Update testbed matrix for v1.12.1
  * kopia/repository/config/aws.go: Set session.Options profile
    from config
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 1.12.1:
  * Change v1.12.1 changelog
  * udmrepo use region specified in BSL when s3URL is empty
  * Make Windows build skip BlockMode code.
  * Add v1.12.1 changelog
  * Import auth provider plugins
  * issue #6807: Retry failed create when using generateName
  * Fix CVE-2023-39325.
  * Perf improvements for existing resource restore
  * fix issue 6647
  * Add doc links for new features to release note
  * issue 6734: spread backup pod evenly
  * Replace the base image with paketobuildpacks image
  * [Cherry-pick v1.12]Keep the logs info ns/name is the same with
    other modules.
  * Code clean for backup cmd client. (#6750)
  * Add support for block volumes (#6680) (#6897)
  * Remove legacy label version check, to be added back when
    version is known
  * changelog
  * Handle 1.27 k8s job label changes
  * Fix some wrong logs and code clean.
  * Add go clean in Dockerfile and action. (#6896)
  * code clean for repository (#6768)
  * issue 6880: set ParallelUploadAboveSize as MaxInt64
  * Rename the changelog
  * Add 'orLabelSelector' for backup, restore command
  * issue: move plugin depdending podvolume functions to util pkg
  * issue 6786:always delete VSC regardless of the deletion policy
* Fri Sep 22 2023 kastl@b1-systems.de
- Update to version 1.12.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.12.0
  * Breaking changes
  - Prior to v1.12, the parameter uploader-type for Velero
    installation had a default value of "restic". However,
    starting from this version, the default value has been
    changed to "kopia". This means that Velero will now use Kopia
    as the default path for file system backup.
  - The ways of setting CSI snapshot time have changed in v1.12.
    First, the sync waiting time for creating a snapshot handle
    in the CSI plugin is changed from the fixed 10 minutes into
    backup.Spec.CSISnapshotTimeout. The second, the async waiting
    time for VolumeSnapshot and VolumeSnapshotContent's status
    turning into ReadyToUse in operation uses the operation's
    timeout. The default value is 4 hours.
  - As from Velero helm chart v4.0.0, it supports multiple BSL
    and VSL, and the BSL and VSL have changed from the map into a
    slice, and this breaking change is not backward compatible.
    So it would be best to change the BSL and VSL configuration
    into slices before the Upgrade.
  - Prior to v1.12, deleting the Velero namespace would easily
    remove all the resources within it. However, with the
    introduction of finalizers attached to the Velero CR
    including restore, dataupload, and datadownload in this
    version, directly deleting Velero namespace may get stuck
    indefinitely because the pods responsible for handling the
    finalizers might be deleted before the resources attached to
    the finalizers. To avoid this issue, please use the command
    velero uninstall to delete all the Velero resources or ensure
    that you handle the finalizer appropriately before deleting
    the Velero namespace.
  * Limitations/Known issues
    The Azure plugin supports Azure AD Workload identity way, but
    it only works for Velero native snapshots. It cannot support
    filesystem backup and snapshot data mover scenarios.
  * Upgrading
    https://velero.io/docs/v1.12/upgrade-to-1.12/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.11.1:
  * Add v1.11.1 changelog. (#6522)
  * Integrate pushing to docker hub and gcr.io in one docker build
    and push command.
  * Fix release-1.11 push github action out of space issue. (#6500)
  * Add support for OpenStack CSI drivers topology keys
  * Bump Golang to v1.20.6 for release-1.11.
  * fix-issue-6297
  * Restore Endpoints before Services (#6316)
  * Fix status.progress not getting updated for backup
  * Make the E2E testing pods obey the restricted pod security
    standard.
  * Fix issue 6182
  * Update Golang to v1.20 for release-1.11 branch. (#6159)
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.11.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.11.0
  * Breaking changes
    The Velero CSI plugin now determines whether to restore
    Volume's data from snapshots on the restore's restorePVs
    setting. Before v1.11, the CSI plugin doesn't check the
    restorePVs parameter setting.
  * Upgrading
    Due to the major changes of file system backup, the old upgrade
    steps are not suitable any more.
    https://velero.io/docs/v1.11/upgrade-to-1.11/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.3:
  * Using gcr.io as velero image registry
  * 1.10.3 change log
  * fix issue 6182
  * Bump v1.10's Golang version to v1.20
  * Ignore not found error during patching managedFields (#6135)
  * fix issue 5972
  * E2E test can read VC credential secret according to vSphere CSI
    driver version.
  * Restore Services before Clusters
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.2:
  * fix main CI problem 02
  * fix main CI disk space error
  * Roll back pkg client code for Velero server
  * 1.10.2 change log
  * Update distroless image and fix CVE-2022-41717 for release-1.10
  * Set Kopia IgnoreUnknownTypes in ErrorHandlingPolicy to True for
    ignoring backup unknown file type
  * Add labels for created namespace during velero installation to
    adopt k8s v1.25's PSS and PSA.
  * Restore finalizer and managedFields (#5877)
  * Publish backup results extracted from backup logs
  * Add secret restore item action to handle service account token secret
  * move UpdatePVXStatusToFailed to controller pkg
  * Use updated PVB/PVR for patching Failed Phase during startup
  * Remove container-builder-env section.
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.1:
  * Fix Restic v0.14.0 HIGH grade CVEs.
  * add change log
  * bump up golang net
  * add 1.10.1 changelog
  * bump up to golang 1.18.10
  * Add GOARM in Restic builder. Add PR container build action.
  * Remove container-builder-env section.
  * Fix Dockerfile issue.
  * Add Restic builder in Dockerfile.
  * fix issue 5696
  * Fix error with Restic backup empty volumes
  * Fix changelog
  * Prevent nil panic on exec restore hooks (#5675)
  * Fix CVEs scanned by trivy
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.10.0
  * Upgrading
    Due to the major changes of file system backup, the old upgrade
    steps are not suitable any more.
    https://velero.io/docs/v1.10/upgrade-to-1.10/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to 1.9.6:
  * Bump up Golang version and fix CVEs. (#5884, @blackpiglet)
  * Add labels for velero installed namespace to support PSA.
    (#5887, @blackpiglet)
  * Fix Dockerfile issue. (#5761, @blackpiglet)
  * Add PR container build action, which will not push image. Add
    GOARM parameter. (#5777, @blackpiglet)
  * Correct PVB/PVR Failed Phase patching during startup (#5829,
    @kaovilai)
- Update to version 1.9.5:
  * Add GOARM for restic compile failure
  * Add changelogs for v1.9.5
  * Add Restic builder in Dockerfile.
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.9.4:
  * Rollback compile restic
  * Fix CVE for trivy scan
  * remove old versions from kind CI (#5627)
  * Restore ClusterBootstrap before Cluster
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.9.3:
  * Fix restic cross platform compile
  * Add compile restic binary for CVE fix
  * Fix controller problematic log output
  * Bump up golang version to 1.18.8
  * Generate v1.9.3 changelog (#5538)
  * Enhance the restore priorities list to support specifying the
    low prioritized resources that need to be restored in the last
  * Fix v1.9.3 CSI VolumeSnapshot status duplicate issue.
  * Bump up the distroless image to the latest version (#5500)
  * Cherry pick 5388 to v1.9.3 (#5482)
  * Fix CVE-2022-27191
  * Change the name of changelog file and update code/doc to pass
    checking
  * update k8s.io dependencies to 0.24.0
  - This also required an update to use github.com/bombsimon/logrusr/v3
  * 'WithClusterName' removed as per the k8s doc reasoning:
  - https://github.com/kubernetes/apimachinery/blob/release-1.24/pkg/apis/meta/v1/types.go\#L257-L259
  - ('ClusterName was a legacy field that was always cleared by
    the system and never used')
  - Test was updated accordingly
  * Exclude "csinodes.storage.k8s.io" and
    "volumeattachments.storage.k8s.io" from backup and restore by
    default.
  * Skip the exclusion check for additional resources returned by
    BIA
  * Amend changelog for v1.9.2
  * Generate changelog for v1.9.2
  * increase restic ensure repo timeout
  * Fix CVE-2022-1962 by bumping up golang verison to 1.17.13
    (#5286)
  * Add support to download CSI json from object store
  * fix edge cases for already exists resources
  * check vsc null pointer
  * Check for empty ns list before checking nslist[0]
  * Don't panic when storageClassName is not set in stateful sets
  * Fix code spell check fail
* Tue Nov  8 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.2:
  * Add annotation "pv.kubernetes.io/migrated-to" for CSI checking.
  * Fix CVE-2022-1962 by bumping up golang version to 1.17.13
  * Improvement to the CSI plugin in plugin v0.3.0
  * Skip registering "crd-remap-version" plugin when feature flag "EnableAPIGroupVersions" is set
  * Refactored the controllers using Kubebuilder v3
  * Optionally restore status on selected resources
    The restoreStatus option has been added to the CLI and Restore spec to enable
    you to control the group of resources whose status will be restored.
  * ExistingResourcePolicy in the restore API
  * Upgrade integrated Restic version and add skip TLS validation in Restic command
- Update to version 1.9.1:
  * Bump up base image and package version to fix CVEs
  * Amend changelogs for v1.9.1
  * Make CSI snapshot creation timeout configurable for backup and schedule.
  * Add annotation "pv.kubernetes.io/migrated-to" for CSI checking.
  * Generate the changelog for v1.9.1 (#5176)
  * Generate the changelog for v1.9.1
  * Fix restic backups to multiple backup storage locations bug
  * Skip registering "crd-remap-version" plugin when feature flag (#5165) (#5173)
  * Delay CA file deletion in PVB controller
  * Modify BackupStoreGetter to avoid BSL spec changes
  * Fix bsl validation bug
- Update to version 1.9.0:
  * Add changelog for rc2
  * When spec.RestoreStatus is empty, don't restore status
  * Fix tag release error
  * Bumpup plugin version for Velero 1.9 E2E test
  * Fix wrong bucket issue in BSL deletion E2E test
  * Pin the base image and golang image for v1.9.0 release
  * Add more explanation for gen-docs parameters
  * Amend doc 1.9 version
  * Add Changelog and Docs for v1.9
  * Enhance checkpoint of bsl deletion
  * Add more information for failing to get path or snapshot in
    restic backup and restore.
  * Update release instruction
  * Bugs fixing: use patch to update status and set default GC
    period
  * Undo setting the VSC's deletion policy during backup
  * Fix ordered resources cmd Stdout already set error
  * Disable status as sub resource in CRDs
  * Fix E2E test [Backups][Deletion][Restic] on GCP.
  * Mark in-progress CRs as failed when starting the server
  * Fix nightly running failure
  * Add more details about restore workflow (#4928)
  * add site bio/img for maintainer/contributor shubham-pampattiwar
  * Update the doc of CSI support
  * Bump up kind version to support Kubernetes 1.24
  * Add changelog
  * Add docs
  * Add details about using multiple volume snapshot locations and
    restic
  * Cleanup resetStatus
  * fix flag typo
  * Remove break line
  * Propose Shubham Pampattiwar as a maintainer
  * Include moer details
  * Update docs for flag to skip TLS validation
  * Make updates from review
  * Adds informaiton about resticRepoPrefix
  * Fix typos
  * Add schedule ordered resources test
  * Refactor to simplify
  * Enhance the map flag to support parsing input value contains
    entry delimiters
  * Make velero completion zsh command output can be used by
    `source` command.
  * Update cluster migration scenario with more details
  * Add resource limits testing information
  * Update wording and add more useful links
  * Remove jenting from maintainers (#4888)
  * Add note about restoring when resource scaled to 0
  * Add setting TTL in backup E2E test
  * Add restore status to cli
  * Update CRDs
  * Update codegen
  * Fixes tests hopefully
  * Add restore status mechanism
  * Add resource status
  * Add StatusUpdater
  * Fix DeepEqual when status is updated
  * add multiple label selector support to backup API
  * Refactor BSL controller with periodical enqueue source.
  * Make garbage collection for expired backups configurable
  * Update compatibility matrix for 1.9
  * fix typo
  * Add supported versions statment to support process page
  * add existingResourcePolicy to Restore API
  * Add Orlin and Abigail in the team on the site
  * Bump up the version of distroless to base-debian11
  * changes according to review comments
  * change func name and repository description
  * Make in-progress PVB/PVR as failed when restic controller
    restarts to avoid hanging backup/restore
  * Add snapshot checkpoint for CSI E2E test and fix CSI snapshot
    name issue
  * Add wording for using commands in hooks
  * continue rather than return for non-matching restore action
    label
  * Remove VolumeSnapshot created during backup, when the
    VolumeSnapshotClass's DeletionPolicy is set to Delete.
  * Make waiting VolumeSnapshot to ready process parallel.
  * Delete orphan CSI snapshots in backup sync controller
  * Add info about enviroment variables in pre/post hooks
  * Update resource filtering page
  * Update headers in supported providers page
  * Add aws limitation for migration, add limitation section
  * Refactor restic repository
  * cleanup restic helper folder when done
  * Update ROADMAP.md with link to wiki and wiki guidance
  * Bump up the version of library go-plugin
  * Change the name of UT to be more consistent
  * Add multiple label selector support to Velero backup /restore
    API
  * design for enabling existing resource policy
  * Refactor backup deletion controller based on kubebuilder
  * Add ClusterClasses to the restore priority list
  * Convert Pod Volume Restore resource/controller to the
    Kubebuilder framework
  * Make in-progress backup/restore as failed when doing the
    reconcile
  * Document steps to update helm chart for each Velero GA release
  * Remove DeletedBackupRequest information
  * Modify CSI VolumeSnapshot metric related code.
  * Add docs for deleting backups
  * Make the vsc created by backup sync controller deletable
  * Return the error when running reconcile to trigger the handling
    logic again
  * Update site/content/docs/main/api-types/restore.md
  * Update integrated Restic version and add insecureSkipTLSVerify
    for Restic CLI
  * Use controller-gen to generate the deep copy methods for
    objects
  * Update according to comments. Remove
    csiVolumeSnapshotsStorageTotal related code.
  * Fix default-backup-ttl not work
  * fix: delete empty backups
  * fix: use the right kind in getRestartableProcess logger
  * Update CRD and GRPC.
  * Add CSI VolumeSnapshot related metrics.
  * Avoid duplicated snapshotting, when CSI is enabled
  * Refactor schedule controller with kubebuilder
  * Add debug switcher for E2E test
  * Rename binary generated by go install cmd/*
  * Support CSI plugin in E2E test
  * Bump up to v1 API for CSI snapshot
  * Fix bug when pushing the build-image
  * Skip podvolumerestore creation when restore excludes pv/pvc
  * Add CSI plugin in E2E test
  * Support multi-upgrade-path in upgrade E2E test
  * Ensure the restore hook applied to new namespace based on the
    mapping
  * Add parameter for e2e test to support modify kibishii install
    path.
  * add bsl and vsl parameter links
  * Add labels to expired backups failing garbage collection.
    (#4757)
  * Update community managers in MAINTAINERS.md
  * metrics: add items gauges
  * Fix the golang lint error: Variable 'session' collides with
    imported package name
  * Correct copyright comment and string compare
  * Remove blocking indexing of our versioned docs (#4750)
  * Insert all restore errors and warnings into restore log (#4743)
  * Plugin versioning design (#4698)
  * clarify date/time (#4745)
  * Remove Bridget from maintainer list
  * Fix format.
  * Add unit tests, change copyright years and revert unrelated
    changes.
  * Add changelog
  * Adding PriorityClass to backup podAction and restore podAction.
  * Support multiple skip option for E2E test
  * Fixed start contributing link (#4723)
  * Add E2E test of bsl deletion
  * Clarify backups that get deleted via object storage sync
  * Support multiple skip option for E2E test
  * Fixed start contributing link (#4723)
  * Update BSL CR as long as there is any error
  * fix broken links in ibm config page (#4715)
  * Remove gcp auth action. Use JSON key as docker login secret
    instead.
  * Change authentication method from workload identity provider to
    service account key.
  * Add e2e for verify snapshto in VSL
  * Modify according to comments.
  * Enable coverage in test.sh and upload to codecov
  * Fix typo on tests fields name and add another test with gesture
    of errors wanted on equals
  * Fix labels removed in ObjectMeta
  * Add support for --pod-labels (#4694)
  * Add skip case support in e2e test
  * Bypass the remap CRD version plugin when v1beta1 CRD is not
    supported
  * Modify according to comments
  * Update --use-owner-references-in-backup description in velero
    command line
  * [fix] Add regional PV support for GKE
  * Append "-dev" suffix for the image tag of release branches
  * Enable building and pushing image for release branches
  * Don't exit when getting no match for grep
  * Remove the office hours from the community page
  * Add backup deletion e2e test
  * [fix] Avoid overwritten hook's exec.container parameter when
    running pod command executor
  * Add CloudCasa to "Adopters of Velero" section on velero.io
    (#4588)
  * Add Xun Jiang's profile information into Velero Website.
    (#4620)
  * Updates to 1.8 changelog
  * Copy edits for 1.8 release notes
  * Update release note to reflect the fix for #1980
  * Add more exempt labels for stalebot (#4641)
  * restic backupper: ignore volumes of non-running pods (#4584)
  * Add delete BSL cleanup highlight and fixed grammar in heading
  * Refine the release note of v1.8
  * Update e2e test image to gcr.io
  * Fix E2E backup namespaces test
  * Add Ming Qiu's profile information into Velero Website's
    contributor list
  * Add GCR login actions
  * Simplify by assuming nil is false and use boolptr util function
  * Add pushing image to GCR in github workflow
  * Make sure the tag-release script fail on any error
  * Add changelog for PR 4436
  * Minor change to trigger GitHub actions
  * Check for nil before logging DefaultVolumestToRestic value
  * Undeprecate the volumesnapshot plugin in the doc
  * Change 1.8 plugins version to release version
  * Fix E2E gcp plugin tag name
  * Add 1.8 plugins map in e2e test
  * Use OrderedResources in schedules (#4550)
  * Run go mod tidy
  * Replace r.Client.Update with patch helper
  * Remove Bridget McErlean from maintainers
  * E2E SSR test add retry mechanism and logs
  * Run go mod tidy
  * Convert PodVolumeBackup to Kubebuilder framework
  * Add timeout for CI e2e job
  * Nominate Xun Jiang and Ming Qiu to become maintainers (#4578)
  * Change dsu-igeek affiliation to Kasten, requires governance
    vote
  * Add continue-on-error in ci e2e test
  * Remove reference of restic_restore_action.go from the doc
  * Upload debug tarball in PR CI E2E pipeline
  * #4067 Initial design of the new plugins - pre-post backup and
    restore (#4083)
  * Add E2E test of backups sync from BSL
  * Fix: skip not mounted volumes when backing up
  * Clarify restore hook includedResources when not specified
    Signed-off-by: Tiger Kaovilai <tkaovila@redhat.com>
  * Fix bug to make the restic prune frequency configurable
  * update migration across different Kubernetes versions section
  * Fix lint issue and test failed
  * update dependancies
  * add changelog
  * Add doc for new secCtx cm key and missing
    secCtxAllowPrivilegeEscalation.
  * Add full support for setting securityContext for restic restore
    container
  Breaking changes
  With bumping up the API to v1 in CSI plugin, the v0.3.0 CSI plugin will only work for Kubernetes v1.20+.
  Upgrading:
  https://velero.io/docs/v1.9/upgrade-to-1.9/
* Thu Mar 17 2022 jenting.hsiao@suse.com
- Update to version 1.8.1:
  * Bump up golang to 1.17.8
  * Generate the changelog for v1.8.1
  * Bypass the remap CRD version plugin when v1beta1 CRD is not supported (#4706)
  * Append "-dev" suffix for the image tag of release branches
  * Enable building and pushing image for release branches
  * Modify according to comments
  * [fix] Add regional PV support for GKE
  * Check for nil before logging DefaultVolumesToRestic value
* Wed Feb 16 2022 jenting.hsiao@suse.com
- Update to version 1.8.0:
  * Undeprecate the volumesnapshot plugin in the doc
  * Clean up the change log
  * cherry pick to 1.8 Change 1.8 plugins version to release version
  * Cherry pick to1.8 - Add 1.8 plugins map in e2e test
  * E2E SSR test add retry mechanism and logs
  * Remove reference of restic_restore_action.go from the doc
  * Pin the base image and golang img for v1.8.0 release
  * Update changelog for v1.8.0 (#4530)
  * Update doc for v1.8
  * E2E test on ssr object with controller namespace mix-ups
  * Check whether the volume is provisioned by CSI driver or not by the annotation as well
  * Support running e2e testing on k8s 1.23.0
  * Check the existence of the expected service when ignoring the NodePort already allocated error
  * Fix E2E upgrade parameter issue caused by previous PR
  * Bump up velero version in upgrade test
  * add links to plugin repos
  * minor typo fixes
  * readme changes
  * Add kubernetes version compatability matrix
  * Initialize the labels field of `velero backup-location create` option
  * Update CSI docs with more context
  * Fix e2e 2500 namespaces scale test timeout problem
  * Add backup deletion e2e test
  * Parse resource from backup tarball directly rather than resolving it via discovery service to avoid #4009 (#4398)
  * Keep the annotation "pv.kubernetes.io/provisioned-by" when restoring PVs
  * Ignore the provided port is already allocated error when restoring the LoadBalancer service (#4462)
  * Return the error when getting backup store in backup deletion controller (#4465)
  * Add changelog.
  * Revert "Migrate backup sync controller from code-generator to kubebuilder (#4423)"
  * Update code standards to direct folks to create changelogs on release… (#4443)
  * Add rbac and annotation test cases
  * Fix statefulsets volumeClaimTemplates storageClassName after use Changing PV/PVC Storage Classes (#4375)
  * Upgrade e2e test vsphere plugin
  * Migrate backup sync controller from code-generator to kubebuilder (#4423)
  * Remove backups and restic repos associated with deleted BSL(s) (#4377)
  * Adds <backup-name>-itemsnapshots.gz file to backup (when provided). (#4429)
  * fix: remove --crds-version in velero install command
  * Consolidated code for resolving actions and plugins into ActionResolver (#4410)
  * Add defaultVolumesToRestic to schedule api docs
  * Fix e2e test failures for the inappropriate optimaze of velero install
  * Limit backup namespaces on test resource filtering cases
  * Added UploadProgressFeature flag to enable UploadProgressMonitoring and ItemSnapshotters
  * feat: improve documentation for reverse selector
  * Bump up Go to 1.17
  * Add resoure filtering test cases
  * Added ItemSnapshotter to the plugin server framework. (#4417)
  * update documentation (#4378)
  * Add restoreactionitem plugin to handle admission webhook configurations
  * Build for darwin_arm64 (#4409)
  * feat: migrate kubebuilder from v2 to v3
  * Update issue template to reference velero debug (#4384)
  * Adjust structure of e2e test codes Put every test moduels into seperate packages and all velero install parameters integrated into one struct
  * Add the key for GKE zone for AZ collection
  * Fix snapshot e2e test issue of jsonpath
  * fix: modify generated from schedule's backup name timestamp to UTC ti… (#4353)
  * Use logrusr instead of zap.
  * ItemSnapshotter plugin APIs.  Addresses #3753 (#4077)
  * Design doc for delete associated backup and restic repos when BSL is deleted (#4297)
  * Fix: add init log option for velero controller-runtime manager.
  * Fix: add init log option for velero controller-runtime manager.
  * Read Availability zone from nodeAffinity requirements
  * Use factory.Namespace() to replace hardcoded velero namespace (#4346)
  * Ignore the `provided port is already allocated` error when restoring the `NodePort` service (#4336)
  * Return the error if velero failed to detect S3 region for restic repo (#4343)
  * Fix: add init log option for velero controller-runtime manager.
  * PV remapClaimRefNS was being skipped when there was no snapshot (#3708)
  * Check the failed phases either when uploading the snapshot in E2E testing (#4162)
  * Only set BSL credential field if provided (#4322)
  * add 4306 changelog
  * - fix buggy pager func fix paging items in to use list options passed by the paging function
  * Verify group before treating resource as cohabitating (#4126)
  * Fix CVE-2020-29652 and CVE-2020-26160 (#4274)
  * Correct the environment variable for azure credential file (#4313)
  * Validation allows empty string namespace
  * Don't create a backup immediately after creating a schedule (#4281)
  * Add daniel to contributor list
  * Update the design of `velero debug` (#4081)
  * Add WenkaiYin to contributor list (#4277)
  * Limit  kubebuilder controllers to work only for objects in own namespaces
  * Namespace validation now allows asterisks
  * Update release instruction
  * Update 1.8 roadmap for Technical health
  * 1.8 roadmap (#4210)
  * Updated Tiltfile to pass REGISTRY env variable to build.sh Set default registry to be docker.io/velero in Tiltfile and example
  * Bump latest doc to v1.7
  * Initial draft of an object graph manifest (#3466)
  * #4040 - documentation - adding more troubleshooting information durin… (#4041)
  * Specify the "--snapshot-volumes=false" option explicitly when running backup with Restic
  * Refine tag-release.sh
* Thu Jan 27 2022 Robert Munteanu <rombert@apache.org>
- Added completion packages
* Fri Dec 10 2021 jenting.hsiao@suse.com
- Update to version 1.7.1:
  * Add change log for 1.7.1
  * add 4358 changelog
  * - fix buggy pager func fix paging items in to use list options passed by the paging function
  * Fix CVE-2020-29652 and CVE-2020-26160 (#4315)
  * Namespace validation now allows asterisks and empty string (#4316)
  * Comment in Dockerfile to explain the digest of base image (#4224)
* Thu Sep 30 2021 jenting.hsiao@suse.com
- Update to version 1.7.0:
  * Specify the "--snapshot-volumes=false" option explicitly when running backup with Restic
  * Pin the base image for v1.7 (#4180)
  * Fix plugins incompatible issue in upgrade test (#4141)
  * run backup/restore describe in debug subcommand (#4161)
  * Recovery the workround for aws pending issue
  * Use velero debug command to dump the logs when case failed
  * Fix the link and content for upgrade instruction
  * Add upgrade instructions for v1.7.0
  * Add upgrade test into E2E tests
  * Generate v1.7 docs
  * Generate 1.7 changelog
  * Add `velero debug` to documentation
  * Validate namespace in velero backup create command (#4057)
  * Empty the "ClusterIPs" along with "ClusterIP" when "ClusterIP" isn't "None" (#4101)
  * pass velero cli executable to crashd
  * Skip restic backup/restore of DownwardAPI volumes (#4076)
  * remove IsUnstructuredCRDReady (#4085)
  * Several fixes to improve the stability of E2E testing (#4056)
  * Enhance e2e test
  * Implement `velero debug` (#4022)
  * Install/uninstall velero by CLI in the E2E test case
  * Fix log print error using a wrong var name (#4063)
  * add changelog
  * fixes for CVE-2021-3121 and CVE-2021-3580
  * new roadmap for 1.7 (#4048)
  * Change the base image to distroless (#4055)
  * internal/delete: fix dropped error (#4016)
  * Add documentation for TLS error 116 (#3811)
  * Page list requests by default (#3823)
  * Wait the namespace deletion completed before removing the CRDs (#4007)
  * Update ibm-config.md (#4024)
  * Changed format of download request name to use a random UUID rather than (#4034)
  * Fix the random failure of E2E test cases (#4005)
  * Use LabelSelector in Action ResourceSelector
  * Skip restore of APIServices managed by Kubernetes
  * Distinguish between different unnamed node ports when preserving
  * Add Kubernetes v1.22 CI test
  * Use appropriate CRD API during readiness check (#4015)
  * Restic Backup: Add check if Pod is successful or failed for emptyDir.… (#3993)
  * pkg/install: fix dropped error
  * Bump up Go to 1.16 (#3990)
  * Select the velero deployment with both label and container name (#3996)
  * Updated uninstall to remove both v1beta1 and v1 CRDs if present (#3997)
  * Patch the resources of velero and kibishii when running E2E testing
  * Adding new meeting details to community documentation page (#4001)
  * enable e2e tests to choose crd apiVersion
  * Control the name of backup used in E2E test to avoid issue on vSphere (#3985)
  * Change CRDs default API version v1
  * Update the Tiltfile to use v1 CRDs
  * Update site documentation
  * Add CI CRD check on K8s v1.21.1
  * Update CI codespell check
  * Add changelog
  * Add new flag --crds-version of default CRD version to generated
  * Run script to generate both v1beta1 and v1 CRDs
  * Update script to generate both v1beta1 and v1 CRDs
  * Fixing multipleNamespaceTest bug - Missing expect statement in test (#3983)
  * Run "Basic" test cases only on Github Action for pull requests (#3989)
  * Bump up vSphere plugin version to v1.1.1
  * Generate test report for the E2E testing
  * Update stale bot setting (#3979)
  * Update upgrade instructions to reference v1.6.2 (#3977)
  * Add the design for `velero debug` (#3973)
  * Fix push-build-image target
  * Change restic image log messages to info level
  * Adding Replicated logo to adopters page - take 2
  * Update k8s libraries to latest patch version (#3953)
  * pkg/restore: fix dropped error
  * Allow registry to be configured at build time
  * Nominate Wenkai Yin to become a maintainer
  * Nominate Daniel Jiang to become a maintainer
  * Enable stale bot
  * Add changelog
  * Upgrade Velero ClusterRoleBinding to use v1 API
  * Fix -install-velero flag for e2e tests
  * Enable the E2E test on Github Action
  * So Long, and Thanks for All the Fish
  * Update upgrade instructions to reference v1.6.1 (#3893)
  * Fix:rss link blindly appends /blog/index.html (#3886)
  * Fix the link of release information (#3883)
  * regression introduced in 1.6 restore progress: fix CR restore (#3845)
  * Added multiple namespace test (#3763)
  * Add Labels field to BackupSpec (#3641)
  * Skip volume restores from projected sources (#3877)
  * API groups e2e tests remove controllers (#3564)
  * fix typos for code spell test
  * skip backuping projected volume
  * Update changelog for new PR.
  * Refactor GetRepoIdentifier tests and add new case
  * Consolidate api clients for e2e tests (#3764)
  * Remove ashish-amarnath as maintainer (#3842)
  * Delete residual file caused by network interruption and so on. Fixes #3204 (#3241)
  * Updated design to take into account protocol buffer limitations. (#3464)
  * Add document describing manual test cases (#3601)
  * Update Enable API Group Versions Feature docs (#3809)
  * Update MinIO docs for correct AWS plugin version (#3814)
  * Added BackupPhaseUploading and BackupPhaseUploadingPartialFailure backup (#3805)
  * Remove Nolan Brubaker from active contributors
  * Remove the [insert current year] in the code standards doc
  * Add information about compression in Velero (#3818)
  * Add PVC UID label to PVR (as we already have for PVB) (#3792)
  * Remove nrb from PR review rotation (#3810)
  * Support pulling plugins by digest (#3803)
  * Update docs to state Kubernetes v1.12 is needed (#3787)
  * Update docs to include schedule backup example (#3478)
  * Add note about updating CRDs during development (#3784)
  * service_action: use unstructured to marshal selective fields  (#3789)
  * Fix gh action (#3743)
  * Changed kibishii wait commands to output stdout/stderr, makes for better debugging (#3762)
  * ✨ ⚠️ Remove CSI volumesnapshot artifact deletion (#3734)
  * Added site bio/img for maintainer/contributor sseago (#3750)
  * Storage Supported Providers hyperlink is updated to refer to the correct path (#3667)
  * Design doc for upload progress monitoring (#3416)
  * Changes to secrets design (#3413)
  * Propose Scott Seago as a maintainer (#3747)
  * A small refactor of the e2e tests (#3726)
  * update other versions
  * fix on-premise `--plugins` flag documentation
  * Shorten OpenStack plugin documentation link text
  * Add cpanato as Emeritus Maintainers (#3725)
  * Fix typo in the restic document (#3728)
  * Fix typo in restic documentation
  * 🐛  Fix plugin name derivation from image name (#3711)
  * Fix misspelled file name (#3712)
  * Docs: include OpenStack plugin for version 1.6
  * Define a Velero release schedule (#3551)
  * Added release criteria to release-instructions (#3598)
  * Improve plugin release instructions (#3591)
  * Fix format
  * Fix path
  * Consolidate config files and fix path
  * Add Abbie to PR review requests
  * Add logo assets
  * Fix incorrect links in BSL docs (#3680)
  * Added Eleanor to Team Bios and to Maintainers page, removed Tim (#3593)
  * Add blog post for Velero 1.6 (#3676)
  * use region input to detect the Bucket region Signed-off-by: Jalaja Ganapathy <jalaja@replicated.com>
  * Docs: Add OpenStack list item to plugin page
  * Docs: include OpenStack plugin in community supported providers
  * Correctly render links with fragments on docs pages
* Fri Aug 13 2021 jenting.hsiao@suse.com
- Update to version 1.6.3:
  * Update changelog for v1.6.3
  * Merge pull request #4028 from zubron/add-restore-item-action-to-skip-automanaged-apiservices
  * Cherry-pick and update changelog for v1.6.3 (#4018)
  * Cherry pick changes for 1.6.3 and add changelog (#4006)
  * Fix bugs of E2E test cases
  * Support both v1beta1 and v1 CRDs for velero
  * Upgrade Velero ClusterRoleBinding to use v1 API (#3995)
* Wed Jul 21 2021 jenting.hsiao@suse.com
- Update to version 1.6.2:
  * Add changelog for v1.6.2
  * Merge pull request #3928 from zubron/customize-velero-image-at-build-time
  * Update k8s libraries to latest patch version (#3953)
* Thu Jun 24 2021 jenting.hsiao@suse.com
- Update to version 1.6.1:
  * Add changelog for v1.6.1
  * regression introduced in 1.6 restore progress: fix CR restore (#3845)
  * Skip volume restores from projected sources (#3877)
  * API groups e2e tests remove controllers (#3564)
  * Merge pull request #3866 from alaypatel07/fix-projected-volume-for-restic
  * Consolidate api clients for e2e tests (#3764)
  * A small refactor of the e2e tests (#3726)
  * 🐛  Fix plugin name derivation from image name (#3711)
* Wed Apr 14 2021 jenting.hsiao@suse.com
- Update to version 1.6.0:
  * Add changelog and docs for v1.6.0
  * Upgrade docs for v1.6.0-rc2 (#3662)
  * Revert printer columns (#3652)
  * Add changelog and docs for v1.6.0-rc.1
  * Allow Dockerfiles to be configurable (#3634)
  * Remove unnecessary check
  * Adress Ashish's second review
  * Runs vSphere tests with snapshots (#3629)
  * Address Ashish's review
  * Addressed Bridget's review
  * Addressed Dave's review
  * Make uninstall more robust and informative
  * Added volume snapshot test for backup/restore. (#3592)
  * Improve GH Action PR assign + labeling (#3584)
  * Update upgrade docs (#3568)
  * Upgrade e2e tests to new plugin versions (v1.2)
  * Restore progress reporting bug fix (#3583)
  * Install plugins for additional BSL in E2E test (#3582)
  * Updated Azure plugin in e2e tests to 1.1.2 (latest) (#3585)
  * Upgrade restic from v0.9.6 to v0.12.0 (#3528)
  * Use Credential from BSL for restic commands  (#3489)
  * Partially revert adding credentials to VSL (#3561)
  * Address review comments
  * Add E2E test for multiple credentials
  * Prefer conditional waiting over magic sleep (#3527)
  * Proposed 1.7.0 roadmap (#3537)
  * Assign a smaller number of reviewers to PRs (#3543)
  * fix broken build (#3525)
  * Pass configured BSL credential to plugin via config (#3442)
  * Restore progress reporting (#3125)
  * Support cli uninstall (#3399)
  * Convert DownloadRequest resource/controller to kubebuilder  (#3004)
  * Update in-code documentation to show resources can be specified with group name (#3498)
  * (low priority) Add port fwding info to Tilt doc (#3424)
  * Combine CRD install verification into 1 job, and update k8s versions (#3448)
  * (low priority) Update to Thompson (#3502)
  * Install CA certificates in Tilt Docker image (#3496)
  * Update PR template to use checkbox task lists (#3492)
  * Use pod namespace from backup when matching PVBs (#3475)
  * added documentation for how velero handles encryption (#3463)
  * E2E tests now run in multiple clouds in addition to KIND (#3286)
  * fix typo in item_hook_handler (#3361)
  * Use controller-runtime client to get restic secrets (#3320)
  * Restore API group version by priority (#3133)
  * Document design doc template (#3443)
  * Really fix the Github pull request template (#3444)
  * Use label to select Velero deployment in plugin cmd (#3447)
  * Remove pull request processing from prow action (#3445)
  * Add changelog
  * Restore CAPI cluster objects in a better order
  * Use correct suffix for Labeler config file (#3441)
  * Pin version of labeler action
  * Better validation
  * Better help messages and validation check
  * Fix typo
  * Add changelog
  * Add credential field to the bsl
  * Enable Prow commands when opening or readying PRs
  * Correct PR template file name
  * Unify labels across GitHub Actions
  * Update version of prow-action (#3434)
  * Add colors to describe command (#3275)
  * Enable automatic labeling of PRs via Actions (#3431)
  * Close issues after 35 total days of inactivity. (#3427)
  * Download restic binary using curl (#3421)
  * feat: support set BackupStorageLocation(BSL) CA certificate (#3167)
  * Modify InitContainer checking function that potentially incurs error (#3198)
  * Instantiate the flag map on set
  * Replace NewObjectBackupStore with interface (#3329)
  * Download restic binary outside container (#3327)
  * Add changelog entry
  * Add snapshot-location set command
  * Add credential arg to snapshot-location create
  * Add credential field to VolumeSnapshotLocation
  * Proposal for handling multiple credential secrets (#2403)
  * remove FAQ pages
  * Added information about minimum space required for Minio install. (#3393)
  * Update docs for running velero locally (#3363)
  * Remove references to zenhub (#3357)
  * Reword message for Q&A issue template
  * Fix typo (#3352)
  * fix(tests): make tests pass?
  * chore(gomod): bump k8s version
  * chore(update): run 'make update'
  * fix(tests): make tests pass
  * fix: apply patch
  * feat(gomod): bump versions
  * chore(changelog): add changelog message
  * refactor(external-snapshotter): bump to v4
  * refactor(gomod): move replaces
  * Add Q&A discussion to issue templates (#3339)
  * Support fish shell completion (#3231)
  * Update docs to clarify backup location and relationship with other data (#3309)
  * Add Tilt configuration to debug using Delve (#3189)
  * Updated for new repository for Kibishii Distributed Data Generator for e2e tests (#3267)
  * Raise logging level for PV deletion timeout (#3316)
  * Minor kubebuilder related items to clean up  (#3180)
  * Download Restic binary and copy into Tilt Velero image (#3310)
  * Increased limit for Velero pod to 512M.  Fixes #3234
  * Capitalize all help messages (#3209)
  * Nominate JenTing Hsiao for core maintainer (#3188)
  * Improve name formatting logic and add more tests
  * Fix path to crds.go file in codespell config (#3185)
  * Minor refactor plus better documentation for naming
  * issue: add flag to the schedule cmd to configure the `useOwnerReferencesInBackup` option  #3176 (#3182)
  * Better name format for init containers
  * Tencent S3 Compatible Support Docs (#3115)
  * Owner reference in backup when created from schedule (#3127)
  * Ignore config/crd/crds/crds.go file in codespell (#3174)
  * Use inline markdown links in tables (#3114)
  * ✨ Add more E2E tests and improvement (#3111)
  * Add changelog
  * Improvements to BSL logic
  * Revert workflow access token changes (#3170)
  * Preserve nodePort support with --preserve-nodeports flag (#3095)
  * Add milestoned issues to their respective board (#3162)
  * Use new repository-local board & github secret (#3163)
  * Change distro (#3166)
  * Draft design doc for restoring API group version by priority level (#3050)
  * feat: support configure BSL CR to indicate which one is the default (#3092)
  * Add Tilt configs (#3119)
  * 🐛 BSLs with validation disabled should be validated at least once (#3084)
  * Expand maintainer documentation (#3102)
  * Organize design docs (#3101)
  * Fix broken docker login action (#3121)
  * Upgrade to Docker provided buildx action for CI (#3110)
  * feat: add delete sub-command for backup-location (#3073)
  * Don't fail backup deletion if downloading tarball fails (#2993)
  * Add an E2E test framework to test Velero across cloud platforms (#3060)
  * 🏃‍♂️ reducing verbosity of another log message (#3109)
  * Modify function name typo (#3106)
  * Fix project automation (#3089)
  * 📖 Add docs to troubleshoot cloud-credentials (#3100)
  * pass annotations from scheduler to created backup (#3067)
  * Update to latest covenant coc (#3076)
  * propose restore progress (#3016)
  * Design doc for RestoreItemAction wait for AdditionalItems to be ready (#2867)
  * 🏃‍♂️ Turn down logging verbosity (#3091)
  * Add instructions to clone repo for examples (#3074)
  * 🏃‍♂️ update setup-kind github actions CI (#3085)
  * Add Dave Uchida (#3077)
  * 📖 use correct link to the minio.md (#3071)
  * Automate adding opened issues to the triage board (#3068)
  * 🐛 Do not run ItemAction plugins for unresolvable types for all types (#3059)
  * .github/workflows: add PR codespell workflow (#3064)
  * Fix various typos found by codespell (#3057)
  * 🐛 Use namespace and name to match PVB to Pod restore (#3051)
  * Add custom 404 page to website (#3056)
  * fixing 'velero.io/change-pvc-node-selector' plugin to fetch configmap using plugin name (#2970)
  * 🏃‍♂ Improve log message clarity (#3047)
  * 📖 Clarify restore hook init container priority (#3030)
  * Add additional printer columns for CRDs (#2881)
  * 📖 fix image links in how-velero-works page (#3031)
  * Add warning to velero version cmd. Fixes #3017 (#3024)
  * fix of microsoft typo in restic docs (#3037)
  * fix minio code samples (#3034)
  * Adding fix for restic init container index on restores. (#3011)
  * Ensure PVs and PVCs remain bound when doing a restore (#3007)
  * Add initial instructions for releasing plugins (#2952)
  * create CRB with velero-<namespace> (#2886)
  * Auto assign reviewers when PR is ready for review (#3006)
  * Check existing remote branches in release script (#2951)
  * Include --validate=false in upgrade instructions (#2969)
  * 📖 document restic limitation of backing only pod volumes (#2976)
  * Bump Go to 1.15 (#2974)
  * Fix BSL controller to avoid invoking init() on all BSLs regardless of ValidationFrequency (#2992)
  * Fix version cmd getting nil pointer (#2996)
  * Centralize + rename controller names and list (#2936)
  * Allow Timezone change in the container (#2944)
  * Update ROADMAP.md (#2986)
  * restore proper lowercase/plural CRD resource (#2949)
  * Stephanie Bauman is leaving the velero project (#2985)
  * Allow remote for release process to be configured (#2950)
  * Improve release docs following v1.5.1 release (#2954)
  * Fix adopters logos (#2968)
  * Don't attempt to publish docker images on forks (#2953)
  * Add Velero Office Hours info (#2962)
  * Fix 'subcommand required' error w/ cobra upgrade (#2947)
  * v1.5 blog post (#2940)
* Thu Apr  8 2021 jenting.hsiao@suse.com
- Update to version 1.5.4:
  * Add cherry-pick commits and changelog for v1.5.4 (#3651)
* Sat Jan 16 2021 jenting.hsiao@suse.com
- Update to version 1.5.3:
  * Add changelog for v1.5.3
  * Increased limit for Velero pod to 512M.  Fixes #3234
  * 🐛 BSLs with validation disabled should be validated at least once (#3084)
  * Don't fail backup deletion if downloading tarball fails (#2993)
  * 🐛 Do not run ItemAction plugins for unresolvable types for all types (#3059)
  * 🐛 Use namespace and name to match PVB to Pod restore (#3051)
  * Adding fix for restic init container index on restores. (#3011)
  * v1.5.2 changelogs and cherry-picks (#3023)
  * Add changelog and docs for v1.5 release (#2941)
  * Spruce up release instructions and release scripts (#2931)
* Tue Nov 10 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.5.2
  - Fix BSL controller to avoid invoking init() on all BSLs regardless of ValidationFrequency (#2992, @betta1)
  - cli: allow creating multiple instances of Velero across two different namespaces (#2886, @alaypatel07)
  - Restore CRD Resource name to fix CRD wait functionality. (#2949, @sseago)
  - Ensure that bound PVCs and PVs remain bound on restore. (#3007, @nrb). This fixes CVE-2020-3996.
* Wed Oct 14 2020 Jan Engelhardt <jengelh@inai.de>
- Avoid double %%setup calls.
* Tue Oct 13 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.5.1
  - Auto Volume Backup Using Restic with --default-volumes-to-restic flag
  - DeleteItemAction plugins
  - Code modernization
  - Restore Hooks: InitContianer Restore Hooks and Exec Restore Hooks
* Fri Jul 31 2020 jenting hsiao <jenting.hsiao@suse.com>
- Add patch: add a flag cacert for velero backup-location create
* Mon Jul 20 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.4.2
  - v1.4.2
  * log a warning instead of erroring if an additional item returned from a plugin can't be found in the Kubernetes API (#2595, @skriss)
  * Adjust restic default time out to 4 hours and base pod resource requests to 500m CPU/512Mi memory. (#2696, @nrb)
  * capture version of the CRD prior before invoking the remap_crd_version backup item action (#2683, @ashish-amarnath)
  - v1.4.0
  * increment restic volumesnapshot count after successful pvb create (#2542, @ashish-amarnath)
  * Add details of CSI volumesnapshotcontents associated with a backup to velero backup describe when the EnableCSI feature flag is given on the velero client. (#2448, @nrb)
  * Allow users the option to retrieve all versions of a given resource (instead of just the preferred version) from the API server with the EnableAPIGroupVersions feature flag. (#2373, @brito-rafa)
  * Changed backup tarball format to store all versions of a given resource, updated backup tarball format to 1.1.0. (#2373, @brito-rafa)
  * allow feature flags to be passed from install CLI (#2503, @ashish-amarnath)
  * sync backups' CSI API objects into the cluster as part of the backup sync controller (#2496, @ashish-amarnath)
  * bug fix: in error location logging hook, if the item logged under the error key doesn't implement the error interface, don't return an error since this is a valid scenario (#2487, @skriss)
  * bug fix: in CRD restore plugin, don't use runtime.DefaultUnstructuredConverter.FromUnstructured(...) to avoid conversion issues when float64 fields contain int values (#2484, @skriss)
  * during backup deletion also delete CSI volumesnapshotcontents that were created as a part of the backup but the associated volumesnapshot object does not exist (#2480, @ashish-amarnath)
  * If plugins don't support the --features flag, don't pass it to them. Also, update the standard plugin server to ignore unknown flags. (#2479, @skriss)
  * At backup time, if a CustomResourceDefinition appears to have been created via the v1beta1 endpoint, retrieve it from the v1beta1 endpoint instead of simply changing the APIVersion. (#2478, @nrb)
  * update container base images from ubuntu:bionic to ubuntu:focal (#2471, @skriss)
  * bug fix: when a resource includes/excludes list contains unresolvable items, don't remove them from the list, so that the list doesn't inadvertently end up matching all resources. (#2462, @skriss)
  * Azure: add support for getting storage account key for restic directly from an environment variable (#2455, @jaygridley)
  * Support to skip VSL validation for the backup having SnapshotVolumes set to false or created with --snapshot-volumes=false (#2450, @mynktl)
  * report backup progress (number of items backed up so far out of an estimated total number of items) during backup in the logs and as status fields on the Backup custom resource (#2440, @skriss)
  * bug fix: populate namespace in logs for backup errors (#2438, @skriss)
  * during backup deletion also delete CSI volumesnapshots that were created as a part of the backup (#2411, @ashish-amarnath)
  * bump Kubernetes module dependencies to v0.17.4 to get fix for kubernetes/kubernetes#86149 (#2407, @skriss)
  * bug fix: save PodVolumeBackup manifests to object storage even if the volume was empty, so that on restore, the PV is dynamically reprovisioned if applicable (#2390, @skriss)
  * Adding new restoreItemAction for PVC to update the selected-node annotation (#2377, @mynktl)
  * Added a --cacert flag to the install command to provide the CA bundle to use when verifying TLS connections to object storage (#2368, @mansam)
  * Added a --cacert flag to the velero client describe, download, and logs commands to allow passing a path to a certificate to use when verifying TLS connections to object storage. Also added a corresponding client config option called cacert which takes a path to a certificate bundle to use as a default when --cacert is not specified. (#2364, @mansam)
  * support setting a custom CA certificate on a BSL to use when verifying TLS connections (#2353, @mansam)
  * adding annotations on backup CRD for k8s major, minor and git versions (#2346, @brito-rafa)
  * When the EnableCSI feature flag is provided, upload CSI VolumeSnapshots and VolumeSnapshotContents to object storage as gzipped JSON. (#2323, @nrb)
  * add CSI snapshot API types into default restore priorities (#2318, @ashish-amarnath)
  * refactoring: wait for all informer caches to sync before running controllers (#2299, @skriss)
  * refactor restore code to lazily resolve resources via discovery and eliminate second restore loop for instances of restored CRDs (#2248, @skriss)
  * upgrade to go 1.14 and migrate from dep to go modules (#2214, @skriss)
  * clarify the wording for restore describe for namespaces included
  - v1.3.2
  * Allow plugins/ as a valid top-level directory within backup storage locations. This directory is a place for plugin authors to store arbitrary data as needed. It is recommended to create an additional subdirectory under plugins/ specifically for your plugin, e.g. plugins/my-plugin-data/. (#2350, @skriss)
  * bug fix: don't panic in velero restic repo get when last maintenance time is nil (#2315, @skriss)
* Tue Mar 24 2020 jenting hsiao <jenting.hsiao@suse.com>
- Pass git tree status = clean to fix `velero version` output Git commit with trailing dash
* Wed Mar 11 2020 Clark Hsu <clark.hsu@suse.com>
- Bump version 1.3.1
* Mon Mar  2 2020 jenting hsiao <jenting.hsiao@suse.com>
- Bump version 1.3.0
* Mon Feb 24 2020 jenting hsiao <jenting.hsiao@suse.com>
- Simplify rpm spec
* Fri Jan  3 2020 Klaus Kämpf <kkaempf@suse.com>
- fix velero-restic-restore-helper package name
* Fri Jan  3 2020 Klaus Kämpf <kkaempf@suse.com>
- Initial package v1.2.0
